==> szip-2.1-1.tar.bz2: include/SZconfig.h <==
/* SZconfig.h.in.  */

/* Define to 1 if you have the <dlfcn.h> header file. */
/* #undef HAVE_DLFCN_H */

/* Define to 1 if you don't have `vprintf' but do have `_doprnt.' */
/* #undef HAVE_DOPRNT */

/* Define if encoding is enabled */
#define HAVE_ENCODING 1

/* Define to 1 if you have the <fcntl.h> header file. */
/* #undef HAVE_FCNTL_H */

/* Define to 1 if you have the <inttypes.h> header file. */
/* #undef HAVE_INTTYPES_H */

/* Define to 1 if you have the <memory.h> header file. */
#define HAVE_MEMORY_H 1

/* Define to 1 if you have the `memset' function. */
/* #undef HAVE_MEMSET */

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
/* #undef HAVE_STRINGS_H */

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <unistd.h> header file. */
/* #undef HAVE_UNISTD_H */

/* Define to 1 if you have the `vprintf' function. */
/* #undef HAVE_VPRINTF */

/* Name of package */
#define SZIP_PACKAGE "szip"

/* Define to the address where bug reports for this package should be sent. */
#define SZIP_PACKAGE_BUGREPORT "help@hdfgroup.org"

/* Define to the full name of this package. */
#define SZIP_PACKAGE_NAME "SZIP"

/* Define to the full name and version of this package. */
#define SZIP_PACKAGE_STRING "SZIP 2.1"

/* Define to the one symbol short name of this package. */
#define SZIP_PACKAGE_TARNAME "szip"

/* Define to the version of this package. */
#define SZIP_PACKAGE_VERSION "2.1"

/* Define to 1 if you have the ANSI C header files. */
#define STDC_HEADERS 1

/* Version number of package */
#define VERSION "2.1"

/* Define to empty if `const' does not conform to ANSI C. */
/* #undef const */

/* Define to `unsigned int' if <sys/types.h> does not define. */
/* #undef size_t */

/* Define if cmake is used and building dynamic libraries */
/* #undef SZIP_BUILT_AS_DYNAMIC_LIB */

==> szip-2.1.1-1.tar.bz2: include/SZconfig.h <==
/* SZconfig.h.in.  */

/* Define to 1 if you have the <dlfcn.h> header file. */
/* #undef HAVE_DLFCN_H */

/* Define to 1 if you don't have `vprintf' but do have `_doprnt.' */
/* #undef HAVE_DOPRNT */

/* Define if encoding is enabled */
#define HAVE_ENCODING 1

/* Define to 1 if you have the <fcntl.h> header file. */
#define HAVE_FCNTL_H 1

/* Define to 1 if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define to 1 if you have the <memory.h> header file. */
#define HAVE_MEMORY_H 1

/* Define to 1 if you have the `memset' function. */
/* #undef HAVE_MEMSET */

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
/* #undef HAVE_STRINGS_H */

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <unistd.h> header file. */
/* #undef HAVE_UNISTD_H */

/* Define to 1 if you have the `vprintf' function. */
/* #undef HAVE_VPRINTF */

/* Name of package */
#define SZIP_PACKAGE "szip"

/* Define to the address where bug reports for this package should be sent. */
#define SZIP_PACKAGE_BUGREPORT "help@hdfgroup.org"

/* Define to the full name of this package. */
#define SZIP_PACKAGE_NAME "szip"

/* Define to the full name and version of this package. */
#define SZIP_PACKAGE_STRING "szip 2.1"

/* Define to the one symbol short name of this package. */
#define SZIP_PACKAGE_TARNAME "szip"

/* Define to the version of this package. */
#define SZIP_PACKAGE_VERSION "2.1"

/* Define to 1 if you have the ANSI C header files. */
#define STDC_HEADERS 1

/* Version number of package */
#define VERSION "2.1"

/* Define to empty if `const' does not conform to ANSI C. */
/* #undef const */

/* Define to `unsigned int' if <sys/types.h> does not define. */
/* #undef size_t */
